# PyRigidBody
![Python Package](https://github.com/beratatmaca/PyRigidBody/actions/workflows/python-package.yml/badge.svg)
![Documentation](https://github.com/beratatmaca/PyRigidBody/actions/workflows/docs.yml/badge.svg)

This package provides two main classes: `RigidBody` and `Marker` for representing 3D rigid bodies and markers in space. It allows applying transformations using homogeneous matrices and supports quaternion or Euler-based rotations.

## Installation

You can install the package via pip

```bash
pip install PyRigidBody
```

## Usage

## License

## Contribution

